CommitDiffSourceCodeType class

A type of SourceCodeType that specifies the commit diff for a pull request on an associated repository.

Constructors

CommitDiffSourceCodeType({String? destinationCommit, String? sourceCommit})
CommitDiffSourceCodeType.fromJson(Map<String, dynamic> json)
factory

Properties

destinationCommit → String?
The SHA of the destination commit used to generate a commit diff.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceCommit → String?
The SHA of the source commit used to generate a commit diff.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited