SourceCodeType class

Specifies the source code that is analyzed in a code review. A code review can analyze the source code that is specified using a pull request diff or a branch in an associated repository.

Constructors

SourceCodeType({CommitDiffSourceCodeType? commitDiff, RepositoryHeadSourceCodeType? repositoryHead})
SourceCodeType.fromJson(Map<String, dynamic> json)
factory

Properties

commitDiff → CommitDiffSourceCodeType?
A SourceCodeType that specifies a commit diff created by a pull request on an associated repository.
final
hashCode → int
The hash code for this object.
no setterinherited
repositoryHead → RepositoryHeadSourceCodeType?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited